/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200809L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <openssl/ssl.h>
#include <openssl/err.h>
#include <openssl/rand.h>
#include <openssl/evp.h>
#include <openssl/ossl_typ.h>
#include <openssl/x509v3.h>
#include <openssl/comp.h>
#define pypy_GENERAL_NAME_dirn(name) (name->d.dirn)
#define pypy_GENERAL_NAME_rid(name) (name->d.rid)
#define pypy_GENERAL_NAME_uri(name) (name->d.uniformResourceIdentifier)
#define pypy_GENERAL_NAME_pop_free(names) (sk_GENERAL_NAME_pop_free(names, GENERAL_NAME_free))
#define pypy_DIST_POINT_fullname(obj) (obj->distpoint->name.fullname)
#if (OPENSSL_VERSION_NUMBER < 0x10100000) || defined(LIBRESSL_VERSION_NUMBER)
#  define COMP_get_name(meth) (meth->name)
#  define COMP_get_type(meth) (meth->type)
#  define X509_NAME_ENTRY_set(ne) (ne->set)
#  define X509_OBJECT_get0_X509(obj) (obj->data.x509)
#  define X509_OBJECT_get_type(obj) (obj->type)
#  define X509_STORE_get0_objects(store) (store->objs)
#  define X509_STORE_get0_param(store) (store->param)
#else
#  define OPENSSL_NO_SSL2
#endif

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef struct ACCESS_DESCRIPTION_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs method", offsetof(platcheck_t, method));
	dump("fldsize method",   sizeof(s.method));
	dump("fldofs location", offsetof(platcheck_t, location));
	dump("fldsize location",   sizeof(s.location));
}

void dump_section_1(void) {
	if ((ASN1_R_HEADER_TOO_LONG) <= 0) {
	    long long x = (long long)(ASN1_R_HEADER_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ASN1_R_HEADER_TOO_LONG);
	    printf("value: %llu\n", x);
	}
}

void dump_section_2(void) {
	if ((CRYPTO_LOCK) <= 0) {
	    long long x = (long long)(CRYPTO_LOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CRYPTO_LOCK);
	    printf("value: %llu\n", x);
	}
}

void dump_section_3(void) {
	if ((ERR_LIB_ASN1) <= 0) {
	    long long x = (long long)(ERR_LIB_ASN1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERR_LIB_ASN1);
	    printf("value: %llu\n", x);
	}
}

void dump_section_4(void) {
	if ((ERR_LIB_PEM) <= 0) {
	    long long x = (long long)(ERR_LIB_PEM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERR_LIB_PEM);
	    printf("value: %llu\n", x);
	}
}

void dump_section_5(void) {
	if ((ERR_LIB_X509) <= 0) {
	    long long x = (long long)(ERR_LIB_X509);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERR_LIB_X509);
	    printf("value: %llu\n", x);
	}
}

void dump_section_6(void) {
	typedef struct GENERAL_NAME_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs type", offsetof(platcheck_t, type));
	dump("fldsize type",   sizeof(s.type));
	s.type = 0; s.type = ~s.type;
	dump("fldunsigned type", s.type > 0);
}

void dump_section_7(void) {
	if ((GEN_DIRNAME) <= 0) {
	    long long x = (long long)(GEN_DIRNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_DIRNAME);
	    printf("value: %llu\n", x);
	}
}

void dump_section_8(void) {
	if ((GEN_DNS) <= 0) {
	    long long x = (long long)(GEN_DNS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_DNS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_9(void) {
	if ((GEN_EDIPARTY) <= 0) {
	    long long x = (long long)(GEN_EDIPARTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_EDIPARTY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_10(void) {
	if ((GEN_EMAIL) <= 0) {
	    long long x = (long long)(GEN_EMAIL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_EMAIL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_11(void) {
	if ((GEN_IPADD) <= 0) {
	    long long x = (long long)(GEN_IPADD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_IPADD);
	    printf("value: %llu\n", x);
	}
}

void dump_section_12(void) {
	if ((GEN_OTHERNAME) <= 0) {
	    long long x = (long long)(GEN_OTHERNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_OTHERNAME);
	    printf("value: %llu\n", x);
	}
}

void dump_section_13(void) {
	if ((GEN_RID) <= 0) {
	    long long x = (long long)(GEN_RID);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_RID);
	    printf("value: %llu\n", x);
	}
}

void dump_section_14(void) {
	if ((GEN_URI) <= 0) {
	    long long x = (long long)(GEN_URI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_URI);
	    printf("value: %llu\n", x);
	}
}

void dump_section_15(void) {
	if ((GEN_X400) <= 0) {
	    long long x = (long long)(GEN_X400);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_X400);
	    printf("value: %llu\n", x);
	}
}

void dump_section_16(void) {
#ifdef OPENSSL_NPN_NEGOTIATED
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_17(void) {
#ifdef SSL_CTRL_SET_TLSEXT_HOSTNAME
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_18(void) {
	if ((NID_X9_62_prime256v1) <= 0) {
	    long long x = (long long)(NID_X9_62_prime256v1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_X9_62_prime256v1);
	    printf("value: %llu\n", x);
	}
}

void dump_section_19(void) {
	if ((NID_ad_OCSP) <= 0) {
	    long long x = (long long)(NID_ad_OCSP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_ad_OCSP);
	    printf("value: %llu\n", x);
	}
}

void dump_section_20(void) {
	if ((NID_ad_ca_issuers) <= 0) {
	    long long x = (long long)(NID_ad_ca_issuers);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_ad_ca_issuers);
	    printf("value: %llu\n", x);
	}
}

void dump_section_21(void) {
	if ((NID_crl_distribution_points) <= 0) {
	    long long x = (long long)(NID_crl_distribution_points);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_crl_distribution_points);
	    printf("value: %llu\n", x);
	}
}

void dump_section_22(void) {
	if ((NID_info_access) <= 0) {
	    long long x = (long long)(NID_info_access);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_info_access);
	    printf("value: %llu\n", x);
	}
}

void dump_section_23(void) {
	if ((NID_subject_alt_name) <= 0) {
	    long long x = (long long)(NID_subject_alt_name);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_subject_alt_name);
	    printf("value: %llu\n", x);
	}
}

void dump_section_24(void) {
	if ((NID_undef) <= 0) {
	    long long x = (long long)(NID_undef);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_undef);
	    printf("value: %llu\n", x);
	}
}

void dump_section_25(void) {
	if ((OBJ_NAME_TYPE_MD_METH) <= 0) {
	    long long x = (long long)(OBJ_NAME_TYPE_MD_METH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OBJ_NAME_TYPE_MD_METH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_26(void) {
	typedef OBJ_NAME platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs alias", offsetof(platcheck_t, alias));
	dump("fldsize alias",   sizeof(s.alias));
	s.alias = 0; s.alias = ~s.alias;
	dump("fldunsigned alias", s.alias > 0);
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
}

void dump_section_27(void) {
#ifdef OPENSSL_NO_ECDH
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_28(void) {
#ifdef OPENSSL_NO_SSL2
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_29(void) {
#ifdef OPENSSL_NO_SSL3
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_30(void) {
#ifdef OPENSSL_NO_TLSEXT
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_31(void) {
#ifdef OPENSSL_NPN_NEGOTIATED
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_32(void) {
	if ((PEM_R_NO_START_LINE) <= 0) {
	    long long x = (long long)(PEM_R_NO_START_LINE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_NO_START_LINE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_33(void) {
#ifdef SSLEAY_VERSION
	int i;
	const char *p = SSLeay_version(SSLEAY_VERSION);
	dump("defined", 1);
	for (i = 0; p[i] != 0; i++ ) {
	  printf("value_%d: %d\n", i, (int)(unsigned char)p[i]);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_34(void) {
	if ((SSL_AD_HANDSHAKE_FAILURE) <= 0) {
	    long long x = (long long)(SSL_AD_HANDSHAKE_FAILURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_HANDSHAKE_FAILURE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_35(void) {
	if ((SSL_AD_INTERNAL_ERROR) <= 0) {
	    long long x = (long long)(SSL_AD_INTERNAL_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_INTERNAL_ERROR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_36(void) {
	if ((SSL_ERROR_SSL) <= 0) {
	    long long x = (long long)(SSL_ERROR_SSL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_SSL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_37(void) {
	if ((SSL_ERROR_SYSCALL) <= 0) {
	    long long x = (long long)(SSL_ERROR_SYSCALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_SYSCALL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_38(void) {
	if ((SSL_ERROR_WANT_CONNECT) <= 0) {
	    long long x = (long long)(SSL_ERROR_WANT_CONNECT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_WANT_CONNECT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_39(void) {
	if ((SSL_ERROR_WANT_READ) <= 0) {
	    long long x = (long long)(SSL_ERROR_WANT_READ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_WANT_READ);
	    printf("value: %llu\n", x);
	}
}

void dump_section_40(void) {
	if ((SSL_ERROR_WANT_WRITE) <= 0) {
	    long long x = (long long)(SSL_ERROR_WANT_WRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_WANT_WRITE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_41(void) {
	if ((SSL_ERROR_WANT_X509_LOOKUP) <= 0) {
	    long long x = (long long)(SSL_ERROR_WANT_X509_LOOKUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_WANT_X509_LOOKUP);
	    printf("value: %llu\n", x);
	}
}

void dump_section_42(void) {
	if ((SSL_ERROR_ZERO_RETURN) <= 0) {
	    long long x = (long long)(SSL_ERROR_ZERO_RETURN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_ZERO_RETURN);
	    printf("value: %llu\n", x);
	}
}

void dump_section_43(void) {
	if ((SSL_FILETYPE_ASN1) <= 0) {
	    long long x = (long long)(SSL_FILETYPE_ASN1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_FILETYPE_ASN1);
	    printf("value: %llu\n", x);
	}
}

void dump_section_44(void) {
	if ((SSL_FILETYPE_PEM) <= 0) {
	    long long x = (long long)(SSL_FILETYPE_PEM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_FILETYPE_PEM);
	    printf("value: %llu\n", x);
	}
}

void dump_section_45(void) {
	if ((SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER) <= 0) {
	    long long x = (long long)(SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER);
	    printf("value: %llu\n", x);
	}
}

void dump_section_46(void) {
	if ((SSL_MODE_AUTO_RETRY) <= 0) {
	    long long x = (long long)(SSL_MODE_AUTO_RETRY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_MODE_AUTO_RETRY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_47(void) {
	if ((SSL_OP_ALL) <= 0) {
	    long long x = (long long)(SSL_OP_ALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_ALL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_48(void) {
	if ((SSL_OP_CIPHER_SERVER_PREFERENCE) <= 0) {
	    long long x = (long long)(SSL_OP_CIPHER_SERVER_PREFERENCE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_CIPHER_SERVER_PREFERENCE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_49(void) {
	if ((SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS) <= 0) {
	    long long x = (long long)(SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_50(void) {
#ifdef SSL_OP_NO_COMPRESSION
	dump("defined", 1);
	if ((SSL_OP_NO_COMPRESSION) <= 0) {
	    long long x = (long long)(SSL_OP_NO_COMPRESSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_COMPRESSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_51(void) {
	if ((SSL_OP_NO_SSLv2) <= 0) {
	    long long x = (long long)(SSL_OP_NO_SSLv2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_SSLv2);
	    printf("value: %llu\n", x);
	}
}

void dump_section_52(void) {
	if ((SSL_OP_NO_SSLv3) <= 0) {
	    long long x = (long long)(SSL_OP_NO_SSLv3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_SSLv3);
	    printf("value: %llu\n", x);
	}
}

void dump_section_53(void) {
	if ((SSL_OP_NO_TLSv1) <= 0) {
	    long long x = (long long)(SSL_OP_NO_TLSv1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_TLSv1);
	    printf("value: %llu\n", x);
	}
}

void dump_section_54(void) {
	if ((SSL_OP_NO_TLSv1_1) <= 0) {
	    long long x = (long long)(SSL_OP_NO_TLSv1_1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_TLSv1_1);
	    printf("value: %llu\n", x);
	}
}

void dump_section_55(void) {
	if ((SSL_OP_NO_TLSv1_2) <= 0) {
	    long long x = (long long)(SSL_OP_NO_TLSv1_2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_TLSv1_2);
	    printf("value: %llu\n", x);
	}
}

void dump_section_56(void) {
	if ((SSL_OP_SINGLE_DH_USE) <= 0) {
	    long long x = (long long)(SSL_OP_SINGLE_DH_USE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_SINGLE_DH_USE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_57(void) {
	if ((SSL_OP_SINGLE_ECDH_USE) <= 0) {
	    long long x = (long long)(SSL_OP_SINGLE_ECDH_USE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_SINGLE_ECDH_USE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_58(void) {
	if ((SSL_RECEIVED_SHUTDOWN) <= 0) {
	    long long x = (long long)(SSL_RECEIVED_SHUTDOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_RECEIVED_SHUTDOWN);
	    printf("value: %llu\n", x);
	}
}

void dump_section_59(void) {
	if ((SSL_TLSEXT_ERR_ALERT_FATAL) <= 0) {
	    long long x = (long long)(SSL_TLSEXT_ERR_ALERT_FATAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_TLSEXT_ERR_ALERT_FATAL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_60(void) {
	if ((SSL_TLSEXT_ERR_NOACK) <= 0) {
	    long long x = (long long)(SSL_TLSEXT_ERR_NOACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_TLSEXT_ERR_NOACK);
	    printf("value: %llu\n", x);
	}
}

void dump_section_61(void) {
	if ((SSL_TLSEXT_ERR_OK) <= 0) {
	    long long x = (long long)(SSL_TLSEXT_ERR_OK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_TLSEXT_ERR_OK);
	    printf("value: %llu\n", x);
	}
}

void dump_section_62(void) {
	if ((SSL_VERIFY_FAIL_IF_NO_PEER_CERT) <= 0) {
	    long long x = (long long)(SSL_VERIFY_FAIL_IF_NO_PEER_CERT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_VERIFY_FAIL_IF_NO_PEER_CERT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_63(void) {
	if ((SSL_VERIFY_NONE) <= 0) {
	    long long x = (long long)(SSL_VERIFY_NONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_VERIFY_NONE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_64(void) {
	if ((SSL_VERIFY_PEER) <= 0) {
	    long long x = (long long)(SSL_VERIFY_PEER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_VERIFY_PEER);
	    printf("value: %llu\n", x);
	}
}

void dump_section_65(void) {
	if ((TLSEXT_NAMETYPE_host_name) <= 0) {
	    long long x = (long long)(TLSEXT_NAMETYPE_host_name);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TLSEXT_NAMETYPE_host_name);
	    printf("value: %llu\n", x);
	}
}

void dump_section_66(void) {
	if ((X509_LU_CRL) <= 0) {
	    long long x = (long long)(X509_LU_CRL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_LU_CRL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_67(void) {
	if ((X509_LU_X509) <= 0) {
	    long long x = (long long)(X509_LU_X509);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_LU_X509);
	    printf("value: %llu\n", x);
	}
}

void dump_section_68(void) {
	if ((X509_R_CERT_ALREADY_IN_HASH_TABLE) <= 0) {
	    long long x = (long long)(X509_R_CERT_ALREADY_IN_HASH_TABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_CERT_ALREADY_IN_HASH_TABLE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_69(void) {
	if ((X509_V_FLAG_CRL_CHECK) <= 0) {
	    long long x = (long long)(X509_V_FLAG_CRL_CHECK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_V_FLAG_CRL_CHECK);
	    printf("value: %llu\n", x);
	}
}

void dump_section_70(void) {
	if ((X509_V_FLAG_CRL_CHECK_ALL) <= 0) {
	    long long x = (long long)(X509_V_FLAG_CRL_CHECK_ALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_V_FLAG_CRL_CHECK_ALL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_71(void) {
	if ((X509_V_FLAG_X509_STRICT) <= 0) {
	    long long x = (long long)(X509_V_FLAG_X509_STRICT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_V_FLAG_X509_STRICT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_72(void) {
	typedef struct asn1_string_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs length", offsetof(platcheck_t, length));
	dump("fldsize length",   sizeof(s.length));
	s.length = 0; s.length = ~s.length;
	dump("fldunsigned length", s.length > 0);
	dump("fldofs data", offsetof(platcheck_t, data));
	dump("fldsize data",   sizeof(s.data));
}

void dump_section_73(void) {
	typedef struct v3_ext_method platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs it", offsetof(platcheck_t, it));
	dump("fldsize it",   sizeof(s.it));
	dump("fldofs d2i", offsetof(platcheck_t, d2i));
	dump("fldsize d2i",   sizeof(s.d2i));
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	printf("-+- 27\n");
	dump_section_27();
	printf("---\n");
	printf("-+- 28\n");
	dump_section_28();
	printf("---\n");
	printf("-+- 29\n");
	dump_section_29();
	printf("---\n");
	printf("-+- 30\n");
	dump_section_30();
	printf("---\n");
	printf("-+- 31\n");
	dump_section_31();
	printf("---\n");
	printf("-+- 32\n");
	dump_section_32();
	printf("---\n");
	printf("-+- 33\n");
	dump_section_33();
	printf("---\n");
	printf("-+- 34\n");
	dump_section_34();
	printf("---\n");
	printf("-+- 35\n");
	dump_section_35();
	printf("---\n");
	printf("-+- 36\n");
	dump_section_36();
	printf("---\n");
	printf("-+- 37\n");
	dump_section_37();
	printf("---\n");
	printf("-+- 38\n");
	dump_section_38();
	printf("---\n");
	printf("-+- 39\n");
	dump_section_39();
	printf("---\n");
	printf("-+- 40\n");
	dump_section_40();
	printf("---\n");
	printf("-+- 41\n");
	dump_section_41();
	printf("---\n");
	printf("-+- 42\n");
	dump_section_42();
	printf("---\n");
	printf("-+- 43\n");
	dump_section_43();
	printf("---\n");
	printf("-+- 44\n");
	dump_section_44();
	printf("---\n");
	printf("-+- 45\n");
	dump_section_45();
	printf("---\n");
	printf("-+- 46\n");
	dump_section_46();
	printf("---\n");
	printf("-+- 47\n");
	dump_section_47();
	printf("---\n");
	printf("-+- 48\n");
	dump_section_48();
	printf("---\n");
	printf("-+- 49\n");
	dump_section_49();
	printf("---\n");
	printf("-+- 50\n");
	dump_section_50();
	printf("---\n");
	printf("-+- 51\n");
	dump_section_51();
	printf("---\n");
	printf("-+- 52\n");
	dump_section_52();
	printf("---\n");
	printf("-+- 53\n");
	dump_section_53();
	printf("---\n");
	printf("-+- 54\n");
	dump_section_54();
	printf("---\n");
	printf("-+- 55\n");
	dump_section_55();
	printf("---\n");
	printf("-+- 56\n");
	dump_section_56();
	printf("---\n");
	printf("-+- 57\n");
	dump_section_57();
	printf("---\n");
	printf("-+- 58\n");
	dump_section_58();
	printf("---\n");
	printf("-+- 59\n");
	dump_section_59();
	printf("---\n");
	printf("-+- 60\n");
	dump_section_60();
	printf("---\n");
	printf("-+- 61\n");
	dump_section_61();
	printf("---\n");
	printf("-+- 62\n");
	dump_section_62();
	printf("---\n");
	printf("-+- 63\n");
	dump_section_63();
	printf("---\n");
	printf("-+- 64\n");
	dump_section_64();
	printf("---\n");
	printf("-+- 65\n");
	dump_section_65();
	printf("---\n");
	printf("-+- 66\n");
	dump_section_66();
	printf("---\n");
	printf("-+- 67\n");
	dump_section_67();
	printf("---\n");
	printf("-+- 68\n");
	dump_section_68();
	printf("---\n");
	printf("-+- 69\n");
	dump_section_69();
	printf("---\n");
	printf("-+- 70\n");
	dump_section_70();
	printf("---\n");
	printf("-+- 71\n");
	dump_section_71();
	printf("---\n");
	printf("-+- 72\n");
	dump_section_72();
	printf("---\n");
	printf("-+- 73\n");
	dump_section_73();
	printf("---\n");
	return 0;
}
